Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1137)

Unified Diff: components/html_viewer/blink_platform_impl.h

Issue 1674903003: Extract shell methods from ApplicationImpl into a base class, and pass this to Initialize() instead. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@mojom
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/html_viewer/ax_provider_apptest.cc ('k') | components/html_viewer/blink_platform_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/html_viewer/blink_platform_impl.h
diff --git a/components/html_viewer/blink_platform_impl.h b/components/html_viewer/blink_platform_impl.h
index 0494d1c62dbf209b55c0bb90ddbe59ff6d82a41f..0f75f2f20e03b40d8306ca2d8eccd5ec4df2980b 100644
--- a/components/html_viewer/blink_platform_impl.h
+++ b/components/html_viewer/blink_platform_impl.h
@@ -24,7 +24,7 @@
#include "third_party/WebKit/public/platform/WebScrollbarBehavior.h"
namespace mojo {
-class ApplicationImpl;
+class Shell;
}
namespace scheduler {
@@ -40,9 +40,9 @@ class WebCookieJarImpl;
class BlinkPlatformImpl : public blink::Platform {
public:
// |app| may be null in tests.
BlinkPlatformImpl(GlobalState* global_state,
- mojo::ApplicationImpl* app,
+ mojo::Shell* shell,
scheduler::RendererScheduler* renderer_scheduler);
~BlinkPlatformImpl() override;
@@ -102,7 +102,7 @@ class BlinkPlatformImpl : public blink::Platform {
static void DestroyCurrentThread(void*);
GlobalState* global_state_;
- mojo::ApplicationImpl* app_;
+ mojo::Shell* shell_;
scoped_refptr<base::SingleThreadTaskRunner> main_thread_task_runner_;
scoped_ptr<blink::WebThread> main_thread_;
base::ThreadLocalStorage::Slot current_thread_slot_;
@@ -40,9 +40,9 @@ class WebCookieJarImpl;
class BlinkPlatformImpl : public blink::Platform {
public:
- // |app| may be null in tests.
+ // |shell| may be null in tests.
BlinkPlatformImpl(GlobalState* global_state,
« no previous file with comments | « components/html_viewer/ax_provider_apptest.cc ('k') | components/html_viewer/blink_platform_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698